import React from 'react';
import { Anchor } from '..';
type AnchorProps = React.ComponentProps<typeof Anchor>;
export type BreadcrumbItemProps = Omit<AnchorProps, 'color' | 'decoration' | 'size'> & {
    text: string;
    currentPage?: boolean;
    as?: React.ElementType;
};
/**
 * BreadcrumbItem is a link component that allows us to use it just like
 * the `anchor` tag or replaced by a technology's routing system
 *
 * @example
 * import { BreadcrumbItem } from '@tok/components';
 *
 *  <BreadcrumbItem
 *    text="acessorios"
 *    href="passHref"
 *  />
 *
 * @example
 * import Link from 'next/link';
 * import { BreadcrumbItem } from '@tok/components';
 *
 *  <BreadcrumbItem
 *    text="acessorios"
 *    href="passHref"
 *    Component={Link}
 *  />
 */
export declare const BreadcrumbItem: ({ text, currentPage, ...props }: BreadcrumbItemProps) => import("react/jsx-runtime").JSX.Element;
type BreadcrumbProps = React.HTMLAttributes<HTMLElement> & {
    children: React.ReactNode;
};
/**
 * A breadcrumb trail consists of a list of links to the parent pages
 * of the current page in hierarchical order.
 */
export declare const Breadcrumb: ({ children, ...props }: BreadcrumbProps) => import("react/jsx-runtime").JSX.Element;
export {};
