import { IconKeys } from '../../../icons';
import { CSS, VariantProps } from '../../../theme';
import { ReactNode } from 'react';
/**
 * These typings were inspired by this repository
 * @see https://github.com/kripod/react-polymorphic-box
 *
 * They solve the polymorphism problem in Stitches
 * @see https://github.com/modulz/stitches/issues/307#issuecomment-779926558
 */
export type ButtonOwnProps<E extends React.ElementType = React.ElementType> = {
    as?: E;
    children: ReactNode;
    loadingMessage?: string;
    icon?: IconKeys;
    disabled?: boolean;
} & VariantProps<typeof StyledButton>;
export type ButtonProps<E extends React.ElementType> = ButtonOwnProps<E> & {
    css?: CSS;
} & Omit<React.ComponentProps<E>, keyof ButtonOwnProps>;
declare const StyledButton: import("@stitches/react/types/styled-component").StyledComponent<"button", {
    loading?: boolean | "true" | undefined;
    fullWidth?: boolean | "true" | "false" | undefined;
    size?: "medium" | "large" | "small" | undefined;
    variant?: "contained" | "outlined" | undefined;
    color?: "primary" | "danger" | undefined;
}, {
    mobile: "(max-width: 32.4375em)";
    tablet: "(min-width: 32.5em)";
    touch: "(max-width: 64em)";
    desktop: "(min-width: 64.0625em)";
    prefersMotion: "(prefers-reduced-motion: no-preference)";
    hoverBased: "(hover: hover)";
    hoverNone: "(hover: none)";
}, import("@stitches/react/types/css-util").CSS<{
    mobile: "(max-width: 32.4375em)";
    tablet: "(min-width: 32.5em)";
    touch: "(max-width: 64em)";
    desktop: "(min-width: 64.0625em)";
    prefersMotion: "(prefers-reduced-motion: no-preference)";
    hoverBased: "(hover: hover)";
    hoverNone: "(hover: none)";
}, {
    fonts: {
        main: string;
    };
    space: {
        100: string;
        200: string;
        300: string;
        400: string;
        500: string;
        600: string;
        700: string;
        800: string;
        900: string;
        1000: string;
        1100: string;
        1200: string;
        1300: string;
        1400: string;
        1500: string;
        1600: string;
    };
    fontSizes: {
        100: string;
        200: string;
        300: string;
        400: string;
        500: string;
        600: string;
        700: string;
    };
    fontWeights: {
        regular: number;
        medium: number;
        bold: number;
    };
    radii: {
        circle: string;
        pill: string;
        100: string;
        200: string;
        300: string;
    };
    lineHeights: {
        tight: number;
        medium: number;
        large: number;
    };
    borderWidths: {
        thin: string;
        medium: string;
        large: string;
    };
    zIndices: {
        100: string;
        200: string;
        300: string;
        400: string;
        max: string;
    };
    shadows: {
        red40: string;
        green40: string;
        gray40: string;
    };
    colors: {
        green10: string;
        green20: string;
        green30: string;
        green40: string;
        green60: string;
        white: string;
        gray10: string;
        gray20: string;
        gray30: string;
        gray40: string;
        gray50: string;
        black: string;
        red10: string;
        red40: string;
        red60: string;
        yellow10: string;
        yellow40: string;
        yellow90: string;
        blue10: string;
        blue90: string;
    };
}, import("@stitches/react/types/config").DefaultThemeMap, {}>>;
export type ButtonPropss<E extends React.ElementType> = ButtonOwnProps<E> & {
    css?: CSS;
} & Omit<React.ComponentProps<E>, keyof ButtonOwnProps>;
export declare function Button<E extends React.ElementType>({ ...props }: ButtonPropss<E>): import("react/jsx-runtime").JSX.Element;
export {};
