import { useCallback, useEffect, useRef } from 'react';
import { isServer } from "../../utils";
import useInterval from "./useInterval";
export function useCarouselAutoplay(autoplayInterval) {
  if (autoplayInterval === void 0) {
    autoplayInterval = 7000;
  }
  var prefersMotion = isServer ? false : window.matchMedia('(prefers-reduced-motion: no-preference)').matches;
  var sliderRef = useRef(null);
  var _useInterval = useInterval(function () {
      var _sliderRef$current;
      (_sliderRef$current = sliderRef.current) == null || _sliderRef$current.next();
    }, prefersMotion ? autoplayInterval : undefined),
    start = _useInterval.start,
    disableAutoplay = _useInterval.stop;
  var enableAutoplay = useCallback(function () {
    var _sliderRef$current2;
    var sliderContainer = (_sliderRef$current2 = sliderRef.current) == null ? void 0 : _sliderRef$current2.parentElement;
    if (!sliderContainer) {
      return;
    }
    var hasFocus = sliderContainer == null ? void 0 : sliderContainer.contains(document.activeElement);

    // if the mouse is out but the focus is still inside, don't start the autoplay
    // the focusout event listener is triggered quickly when we tab inside the carousel, so we need a double check
    if (!hasFocus) {
      start();
    }
  }, [start, sliderRef]);
  useEffect(function () {
    var _sliderRef$current3;
    var sliderContainer = (_sliderRef$current3 = sliderRef.current) == null ? void 0 : _sliderRef$current3.parentElement;
    if (!prefersMotion || !sliderContainer) {
      return;
    }
    sliderContainer.addEventListener('mouseenter', disableAutoplay);
    sliderContainer.addEventListener('mouseleave', enableAutoplay);
    sliderContainer.addEventListener('focusin', disableAutoplay);
    sliderContainer.addEventListener('focusout', enableAutoplay);
    return function () {
      sliderContainer.addEventListener('mouseenter', disableAutoplay);
      sliderContainer.addEventListener('mouseleave', enableAutoplay);
      sliderContainer.removeEventListener('focusin', disableAutoplay);
      sliderContainer.removeEventListener('focusout', enableAutoplay);
    };
  }, [enableAutoplay, disableAutoplay, prefersMotion]);
  return sliderRef;
}