import { ComponentProps, ReactNode } from 'react';
import { CSS } from '../../../theme';
import { Anchor } from '..';
type LinkProps = Omit<ComponentProps<typeof Anchor>, 'color' | 'decoration'>;
export type FormControlProps = {
    /**
     * The ID of the element to be controlled
     */
    id: string;
    /**
     * The label that will describe the content to be controlled
     */
    label: string;
    /**
     * The element to be controlled
     */
    children: ReactNode;
    /**
     * Displays whether or not the element is required
     */
    required?: boolean;
    /**
     * Makes the error message visible
     */
    error?: boolean;
    /**
     * A text that describes what is wrong
     */
    errorMessage?: string;
    /**
     * A message that will be displayed when interacting with the hint component
     */
    tooltipMessage?: string;
    /**
     * Displays an Anchor
     */
    link?: LinkProps;
    /**
     * The label direction
     */
    direction?: 'column' | 'row';
    css?: CSS;
    className?: string;
    /**
     * The overflow behavior
     */
    overflow?: 'hidden' | 'unset';
};
/**
 * Provides context for form inputs.
 */
export declare const FormControl: ({ id, label, error, errorMessage, tooltipMessage, link, required, children, direction, css, className, overflow, }: FormControlProps) => import("react/jsx-runtime").JSX.Element;
export {};
