import { styled } from "../../../theme";

/**
 * Quickly manage the layout, alignment, and sizing of grid columns,
 * navigation, components, and more with a full suite of responsive
 * grid utilities. For more complex implementations, custom CSS
 * may be necessary.
 **/
export var Grid = styled('div', {
  display: 'grid',
  defaultVariants: {
    align: 'start'
  },
  variants: {
    align: {
      start: {
        alignItems: 'start'
      },
      center: {
        alignItems: 'center'
      },
      end: {
        alignItems: 'end'
      },
      stretch: {
        alignItems: 'stretch'
      },
      baseline: {
        alignItems: 'baseline'
      }
    },
    justify: {
      start: {
        justifyContent: 'start'
      },
      center: {
        justifyContent: 'center'
      },
      end: {
        justifyContent: 'end'
      },
      between: {
        justifyContent: 'space-between'
      }
    },
    flow: {
      row: {
        gridAutoFlow: 'row'
      },
      column: {
        gridAutoFlow: 'column'
      },
      dense: {
        gridAutoFlow: 'dense'
      },
      rowDense: {
        gridAutoFlow: 'row dense'
      },
      columnDense: {
        gridAutoFlow: 'column dense'
      }
    },
    columns: {
      1: {
        gridTemplateColumns: 'repeat(1, 1fr)'
      },
      2: {
        gridTemplateColumns: 'repeat(2, 1fr)'
      },
      3: {
        gridTemplateColumns: 'repeat(3, 1fr)'
      },
      4: {
        gridTemplateColumns: 'repeat(4, 1fr)'
      }
    },
    gap: {
      100: {
        gap: '$100'
      },
      200: {
        gap: '$200'
      },
      300: {
        gap: '$300'
      },
      400: {
        gap: '$400'
      },
      500: {
        gap: '$500'
      },
      600: {
        gap: '$600'
      },
      700: {
        gap: '$700'
      },
      800: {
        gap: '$800'
      }
    },
    columnGap: {
      100: {
        columnGap: '$100'
      },
      200: {
        columnGap: '$200'
      },
      300: {
        columnGap: '$300'
      },
      400: {
        columnGap: '$400'
      },
      500: {
        columnGap: '$500'
      },
      600: {
        columnGap: '$600'
      },
      700: {
        columnGap: '$700'
      },
      800: {
        columnGap: '$800'
      }
    },
    rowGap: {
      100: {
        rowGap: '$100'
      },
      200: {
        rowGap: '$200'
      },
      300: {
        rowGap: '$300'
      },
      400: {
        rowGap: '$400'
      },
      500: {
        rowGap: '$500'
      },
      600: {
        rowGap: '$600'
      },
      700: {
        rowGap: '$700'
      },
      800: {
        rowGap: '$800'
      }
    }
  }
});