import { useMemo } from 'react';
export var DOTS = '...';
var range = function range(start, end) {
  var length = end - start + 1;
  return Array.from({
    length: length
  }, function (_, idx) {
    return idx + start;
  });
};
var DIFFERENT_ELEMENTS = 5;
export var usePagination = function usePagination(_ref) {
  var count = _ref.count,
    _ref$siblingRange = _ref.siblingRange,
    siblingRange = _ref$siblingRange === void 0 ? 1 : _ref$siblingRange,
    currentPage = _ref.currentPage;
  var paginationRange = useMemo(function () {
    // Pages count is determined as siblingRange + firstPage + lastPage + currentPage + 2*DOTS
    var totalPageNumbers = siblingRange * 2 + DIFFERENT_ELEMENTS;
    var canShowAllPages = count <= totalPageNumbers;
    if (canShowAllPages) {
      return range(1, count);
    }
    var leftSiblingIndex = Math.max(currentPage - siblingRange, 1);
    var rightSiblingIndex = Math.min(currentPage + siblingRange, count);

    /*
      We do not want to show dots if there is only one position left
      after/before the left/right page count as that would lead to a change if our Pagination
      component size which we do not want
    */
    var shouldShowLeftDots = leftSiblingIndex > 2;
    var shouldShowRightDots = rightSiblingIndex < count - 2;
    var firstPageIndex = 1;
    var lastPageIndex = count;
    if (!shouldShowLeftDots && shouldShowRightDots) {
      var leftItemCount = 3 + 2 * siblingRange;
      var leftRange = range(1, leftItemCount);
      return [].concat(leftRange, [DOTS, count]);
    }
    if (shouldShowLeftDots && !shouldShowRightDots) {
      var rightItemCount = 3 + 2 * siblingRange;
      var rightRange = range(count - rightItemCount + 1, count);
      return [firstPageIndex, DOTS].concat(rightRange);
    }

    // shouldShowLeftDots && shouldShowRightDots
    var middleRange = range(leftSiblingIndex, rightSiblingIndex);
    return [firstPageIndex, DOTS].concat(middleRange, [DOTS, lastPageIndex]);
  }, [count, siblingRange, currentPage]);
  return paginationRange;
};