import * as Slider from '@radix-ui/react-slider';
import { forwardRef, useCallback, useState } from 'react';
import { styled } from "../../../theme";
import { Flex } from "../Flex";
import { Typography } from "../Typography";
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
var SliderRoot = styled(Slider.Root, {
  alignItems: 'center',
  display: 'flex',
  height: '1.25rem',
  position: 'relative',
  touchAction: 'none',
  userSelect: 'none',
  width: '100%'
});
var SliderTrack = styled(Slider.Track, {
  backgroundColor: '$gray20',
  borderRadius: '9999px',
  flexGrow: 1,
  height: '0.25rem',
  position: 'relative'
});
var SliderRange = styled(Slider.Range, {
  backgroundColor: '$green40',
  borderRadius: '9999px',
  height: '100%',
  position: 'absolute'
});
var SliderThumb = styled(Slider.Thumb, {
  backgroundColor: '$green40',
  borderRadius: 10,
  boxShadow: '0 2px 10px $black',
  display: 'block',
  height: '1.313rem',
  width: '1.313rem',
  '&:hover': {
    backgroundColor: '$green40'
  },
  '&:focus': {
    outline: 'none',
    boxShadow: "0 0 0 5px $green40"
  }
});
var formatCurrency = function formatCurrency(value) {
  return new Intl.NumberFormat('pt-BR', {
    style: 'currency',
    currency: 'BRL'
  }).format(value);
};
var displayValue = function displayValue(value, isCurrency) {
  var formattedValue = formatCurrency(value);
  return /*#__PURE__*/_jsx(Typography, {
    size: '300',
    weight: 'medium',
    color: 'gray50',
    children: isCurrency ? formattedValue : value
  });
};
export var Range = /*#__PURE__*/forwardRef(function (props, ref) {
  var _props$isCurrency = props.isCurrency,
    isCurrency = _props$isCurrency === void 0 ? false : _props$isCurrency,
    minValue = props.minValue,
    maxValue = props.maxValue,
    step = props.step,
    _props$startValues = props.startValues,
    startValues = _props$startValues === void 0 ? [minValue, maxValue] : _props$startValues,
    onValueCommit = props.onValueCommit;
  var _useState = useState(startValues),
    rangeValues = _useState[0],
    setRangeValues = _useState[1];
  var handleValueChange = useCallback(function (newRangeValues) {
    setRangeValues(newRangeValues);
  }, []);
  return /*#__PURE__*/_jsxs(Flex, {
    direction: "column",
    children: [/*#__PURE__*/_jsxs(SliderRoot, {
      min: minValue,
      max: maxValue,
      value: rangeValues,
      minStepsBetweenThumbs: 0.1,
      onValueChange: handleValueChange,
      step: step || 1,
      ref: ref,
      onValueCommit: onValueCommit,
      children: [/*#__PURE__*/_jsx(SliderTrack, {
        "data-testid": "slider-track",
        children: /*#__PURE__*/_jsx(SliderRange, {})
      }), /*#__PURE__*/_jsx(SliderThumb, {
        "aria-label": "Menor valor"
      }), /*#__PURE__*/_jsx(SliderThumb, {
        "aria-label": "Maior valor"
      })]
    }), /*#__PURE__*/_jsxs(Flex, {
      justify: "between",
      css: {
        marginTop: '$100'
      },
      children: [displayValue(rangeValues[0], isCurrency), displayValue(rangeValues[1], isCurrency)]
    })]
  });
});
Range.displayName = 'Range';