import { styled } from "../../../theme";

/**
 * Use the Typography component to quickly manage the text into interface.
 * For more complex implementations, custom CSS may be necessary.
 *
 * The default rendered component will be a paragraph, so in some situations
 * it will be necessary to use the stitches polymorphism API and change
 * it to the correct semantic element.
 *
 * @example
 * <Typography as="h1" size="600">A cool heading here</Typography>
 */
export var Typography = styled('p', {
  fontFamily: '$main',
  defaultVariants: {
    size: '400',
    color: 'gray50',
    weight: 'regular',
    fontStyle: 'normal',
    lineHeight: 'medium'
  },
  variants: {
    size: {
      100: {
        fontSize: '$100'
      },
      200: {
        fontSize: '$200'
      },
      300: {
        fontSize: '$300'
      },
      400: {
        fontSize: '$400'
      },
      500: {
        fontSize: '$500'
      },
      600: {
        fontSize: '$600'
      },
      700: {
        fontSize: '$700'
      }
    },
    weight: {
      regular: {
        fontWeight: '$regular'
      },
      medium: {
        fontWeight: '$medium'
      },
      bold: {
        fontWeight: '$bold'
      }
    },
    fontStyle: {
      normal: {
        fontStyle: 'normal'
      },
      italic: {
        fontStyle: 'italic'
      }
    },
    lineHeight: {
      tight: {
        lineHeight: '$tight'
      },
      medium: {
        lineHeight: '$medium'
      },
      large: {
        lineHeight: '$large'
      }
    },
    color: {
      green60: {
        color: '$green60'
      },
      gray40: {
        color: '$gray40'
      },
      gray50: {
        color: '$gray50'
      },
      black: {
        color: '$black'
      },
      red40: {
        color: '$red40'
      },
      white: {
        color: '$white'
      },
      yellow90: {
        color: '$yellow90'
      },
      blue90: {
        color: '$blue90'
      }
    }
  }
});