type SetterOrUpdater<T> = T | ((updater: T) => T);
type Atom<T> = {
    setState: (newValueOrUpdater: SetterOrUpdater<T>) => void;
    getState: () => T;
    subscribe: (onStoreChange: () => void) => () => void;
};
/**
 * An atom represents a global state. The atom() function returns a Atom object.
 *
 * The Atom manages the state changes to know when to notify components subscribing to that store to re-render,
 * so you should use the useStore hook to acess the store state into a react component.
 *
 * The setState method of a atom can be called outside of react components
 *
 * This API is deeply inspired by atom from Recoil
 *
 * @see https://recoiljs.org/docs/api-reference/core/atom/
 */
export declare function atom<T = unknown>(initialState: T): Atom<T>;
/**
 * This hook will subscribe the component to re-render for any changes in the requested state.
 *
 * Returns a tuple where the first element is the value of state and
 * the second element is a setter function that will update the value
 * of the given state when called.
 *
 * @param atom
 * @returns [state, setState]
 * @example
 *
 * const counterAtom = atom(0)
 *
 * // use it only inside a react component
 * const [counter, setCounter] = useAtom(counterAtom)
 *
 * This API is deeply inspired by useRecoilState from Recoil
 *
 * @see https://recoiljs.org/docs/api-reference/core/useRecoilState/
 */
export declare function useAtom<T>(atom: Atom<T>): [T, Atom<T>['setState']];
export {};
