import { mediaQueries } from "../components";

/**
 * mockInitialMedia is a TEST function that allows us to mock the matchMedia property on the window object.
 *
 * It also sets the default media query to be the mobile and touch query.
 */
export function mockInitialMedia() {
  var initialQuery = [mediaQueries['touch'], mediaQueries['desktop']];
  Object.defineProperty(global, 'matchMedia', {
    writable: true,
    value: jest.fn().mockImplementation(function (query) {
      return {
        query: initialQuery.includes(query),
        matches: true,
        media: '',
        onchange: jest.fn(),
        addEventListener: jest.fn(),
        removeEventListener: jest.fn(),
        addListener: jest.fn(),
        removeListener: jest.fn(),
        dispatchEvent: jest.fn()
      };
    })
  });
}
/**
 * changeMedia is a TEST function that allows us to change the media query to check the component display
 *
 * @param newQuery - string or array that contains the mediaQueries keys of the design system
 *
 * @example
 * changeMedia('desktop');
 *
 * window.matchMedia is called and returns true if the query is equal to the desktop one
 *
 * if you want to create a test case that use multiple media queries, you can pass an array of that
 *
 * @example
 * changeMedia(['mobile', 'touch']);
 *
 * window.matchMedia is called and returns true if the query is equal to mobile or touch query
 *
 */
export function changeMedia(newQuery) {
  var newQueryArray = Array.isArray(newQuery) ? newQuery : [newQuery];
  var queries = newQueryArray.map(function (queryLabel) {
    return mediaQueries[queryLabel];
  });
  window.matchMedia = jest.fn().mockImplementation(function (query) {
    return {
      matches: queries.includes(query),
      media: '',
      onchange: jest.fn(),
      addEventListener: jest.fn(),
      removeEventListener: jest.fn(),
      addListener: jest.fn(),
      removeListener: jest.fn(),
      dispatchEvent: jest.fn()
    };
  });
}