/**
 * Make specific property from a type required
 *
 * if you have to convert a type to be specific propertyes be required, you can use RequireField
 *
 * @example
 * type Alphabet = {
 *  case?: string;
 *  letter: number | null | undefined | string;
 *  foo?: number;
 * }
 *
 * type RequiredAlphabet = RequireField<Alphabet, 'case' | 'letter'>;
 *
 * Result:
 *
 * type RequiredAlphabet = {
 *  case: string;
 *  letter: number | null | string;
 *  foo?: number;
 * }
 *
 * RequireField<type, 'A' | 'B'>
 * @param type the type that you want to makes a specfic property required
 * @param union whose required keys are in the union
 */
export type RequireField<T, K extends keyof T> = T & Required<Pick<T, K>>;
