"use strict";

exports.__esModule = true;
exports.BreadcrumbItem = exports.Breadcrumb = void 0;
var _react = _interopRequireDefault(require("react"));
var _theme = require("../../../theme");
var _ = require("..");
var _icons = require("../../../icons");
var _jsxRuntime = require("react/jsx-runtime");
var _excluded = ["text", "currentPage"],
  _excluded2 = ["children"];
function _interopRequireDefault(e) { return e && e.__esModule ? e : { "default": e }; }
function _extends() { return _extends = Object.assign ? Object.assign.bind() : function (n) { for (var e = 1; e < arguments.length; e++) { var t = arguments[e]; for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]); } return n; }, _extends.apply(null, arguments); }
function _objectWithoutPropertiesLoose(r, e) { if (null == r) return {}; var t = {}; for (var n in r) if ({}.hasOwnProperty.call(r, n)) { if (e.indexOf(n) >= 0) continue; t[n] = r[n]; } return t; }
var List = (0, _theme.styled)('ol', {
  display: 'flex',
  flexWrap: 'wrap',
  gap: '$200',
  fontSize: '$300',
  '@desktop': {
    fontSize: '$400'
  }
});
var ListItem = (0, _theme.styled)('li', {
  listStyle: 'none',
  textTransform: 'capitalize',
  display: 'inline-flex',
  gap: '$200',
  alignItems: 'center'
});

/**
 * BreadcrumbItem is a link component that allows us to use it just like
 * the `anchor` tag or replaced by a technology's routing system
 *
 * @example
 * import { BreadcrumbItem } from '@tok/components';
 *
 *  <BreadcrumbItem
 *    text="acessorios"
 *    href="passHref"
 *  />
 *
 * @example
 * import Link from 'next/link';
 * import { BreadcrumbItem } from '@tok/components';
 *
 *  <BreadcrumbItem
 *    text="acessorios"
 *    href="passHref"
 *    Component={Link}
 *  />
 */
var BreadcrumbItem = exports.BreadcrumbItem = function BreadcrumbItem(_ref) {
  var text = _ref.text,
    _ref$currentPage = _ref.currentPage,
    currentPage = _ref$currentPage === void 0 ? false : _ref$currentPage,
    props = _objectWithoutPropertiesLoose(_ref, _excluded);
  return /*#__PURE__*/(0, _jsxRuntime.jsxs)(ListItem, {
    "aria-current": currentPage ? 'page' : undefined,
    children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_.Anchor, _extends({
      color: currentPage ? 'primary' : 'secondary',
      decoration: currentPage ? 'bold' : 'none'
    }, props, {
      children: text
    })), !currentPage && /*#__PURE__*/(0, _jsxRuntime.jsx)(_icons.Icon, {
      label: "chevron-right",
      size: {
        '@initial': '300',
        '@desktop': '400'
      },
      fill: "gray50",
      "aria-hidden": true
    })]
  });
};
/**
 * A breadcrumb trail consists of a list of links to the parent pages
 * of the current page in hierarchical order.
 */
var Breadcrumb = exports.Breadcrumb = function Breadcrumb(_ref2) {
  var children = _ref2.children,
    props = _objectWithoutPropertiesLoose(_ref2, _excluded2);
  var Items = _react["default"].Children.toArray(children);
  var lastItem = Items[Items.length - 1];
  return /*#__PURE__*/(0, _jsxRuntime.jsx)("nav", _extends({
    "aria-label": "trilha de navega\xE7\xE3o"
  }, props, {
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)(List, {
      children: Items.map(function (item) {
        var currentPage = item === lastItem;
        return /*#__PURE__*/_react["default"].cloneElement(item, {
          currentPage: currentPage
        });
      })
    })
  }));
};