"use strict";

exports.__esModule = true;
exports.DialogTrigger = exports.DialogDescription = exports.DialogContent = exports.DialogClose = exports.Dialog = void 0;
var DialogPrimitive = _interopRequireWildcard(require("@radix-ui/react-dialog"));
var _theme = require("../../../theme");
var _ = require("..");
var _react = require("react");
var _VisuallyHidden = require("../VisuallyHidden");
var _jsxRuntime = require("react/jsx-runtime");
var _excluded = ["title", "children", "hiddenTitle", "hiddenCloseButton"];
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { "default": e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n["default"] = e, t && t.set(e, n), n; }
function _extends() { return _extends = Object.assign ? Object.assign.bind() : function (n) { for (var e = 1; e < arguments.length; e++) { var t = arguments[e]; for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]); } return n; }, _extends.apply(null, arguments); }
function _objectWithoutPropertiesLoose(r, e) { if (null == r) return {}; var t = {}; for (var n in r) if ({}.hasOwnProperty.call(r, n)) { if (e.indexOf(n) >= 0) continue; t[n] = r[n]; } return t; }
var contentShow = (0, _theme.keyframes)({
  '0%': {
    opacity: 0,
    transform: 'translate(-50%, -48%) scale(.96)'
  },
  '100%': {
    opacity: 1,
    transform: 'translate(-50%, -50%) scale(1)'
  }
});
var StyledOverlay = (0, _theme.styled)(DialogPrimitive.Overlay, {
  backgroundColor: '$black',
  opacity: '0.2',
  position: 'fixed',
  inset: 0,
  cursor: 'pointer',
  variants: {
    hiddenCloseButton: {
      "true": {
        cursor: 'default'
      }
    }
  }
});
var StyledContent = (0, _theme.styled)(DialogPrimitive.Content, {
  backgroundColor: '$white',
  borderRadius: '$200',
  position: 'fixed',
  top: '50%',
  left: '50%',
  transform: 'translate(-50%, -50%)',
  width: '90vw',
  maxWidth: '39.75rem',
  padding: '$600 $400 $600 $600',
  outline: 'none',
  '@prefersMotion': {
    animation: contentShow + " 150ms cubic-bezier(0.16, 1, 0.3, 1) forwards"
  }
});
var DescriptionBox = (0, _theme.styled)('div', {
  overflowY: 'auto',
  maxHeight: '28.125rem',
  marginTop: '$200',
  '&::-webkit-scrollbar': {
    width: '0.5rem'
  },
  '&::-webkit-scrollbar-track': {
    background: '$gray20',
    borderRadius: '$200'
  },
  '&::-webkit-scrollbar-thumb': {
    background: '$gray40',
    borderRadius: '$200'
  },
  '@desktop': {
    maxHeight: '16.875rem'
  }
});
var StyledDescription = (0, _theme.styled)(DialogPrimitive.Description, {
  fontFamily: '$main',
  color: '$gray50',
  fontSize: '$400',
  lineHeight: '$large'
});
function Content(_ref) {
  var title = _ref.title,
    children = _ref.children,
    hiddenTitle = _ref.hiddenTitle,
    hiddenCloseButton = _ref.hiddenCloseButton,
    props = _objectWithoutPropertiesLoose(_ref, _excluded);
  var TitleContainer = hiddenTitle ? _VisuallyHidden.VisuallyHidden : _react.Fragment;
  return /*#__PURE__*/(0, _jsxRuntime.jsxs)(DialogPrimitive.Portal, {
    children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(StyledOverlay, {
      hiddenCloseButton: hiddenCloseButton,
      "data-testid": "overlay-dialog"
    }), /*#__PURE__*/(0, _jsxRuntime.jsxs)(StyledContent, _extends({}, props, {
      children: [/*#__PURE__*/(0, _jsxRuntime.jsxs)(_.Flex, {
        align: "center",
        justify: "between",
        children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(TitleContainer, {
          children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_.Typography, {
            as: DialogPrimitive.Title,
            color: "gray50",
            weight: "medium",
            size: {
              '@initial': '400',
              '@desktop': '600'
            },
            children: title
          })
        }), !hiddenCloseButton && /*#__PURE__*/(0, _jsxRuntime.jsx)(DialogPrimitive.Close, {
          asChild: true,
          children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_.GhostIconButton, {
            icon: "close",
            label: "Fechar modal",
            size: "600",
            fill: "gray40",
            css: {
              marginLeft: 'auto'
            }
          })
        })]
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(DescriptionBox, {
        className: "dialog-body",
        children: children
      })]
    }))]
  });
}
var Dialog = exports.Dialog = DialogPrimitive.Root;
var DialogTrigger = exports.DialogTrigger = DialogPrimitive.Trigger;
var DialogContent = exports.DialogContent = Content;
var DialogDescription = exports.DialogDescription = StyledDescription;
var DialogClose = exports.DialogClose = DialogPrimitive.Close;