"use strict";

exports.__esModule = true;
exports.Flex = void 0;
var _theme = require("../../../theme");
/**
 * Quickly manage the layout, alignment, and sizing of grid columns,
 * navigation, components, and more with a full suite of responsive
 * flexbox utilities. For more complex implementations, custom CSS
 * may be necessary.
 **/
var Flex = exports.Flex = (0, _theme.styled)('div', {
  display: 'flex',
  variants: {
    direction: {
      row: {
        flexDirection: 'row'
      },
      column: {
        flexDirection: 'column'
      },
      rowReverse: {
        flexDirection: 'row-reverse'
      },
      columnReverse: {
        flexDirection: 'column-reverse'
      }
    },
    align: {
      start: {
        alignItems: 'flex-start'
      },
      center: {
        alignItems: 'center'
      },
      end: {
        alignItems: 'flex-end'
      },
      stretch: {
        alignItems: 'stretch'
      },
      baseline: {
        alignItems: 'baseline'
      }
    },
    justify: {
      start: {
        justifyContent: 'flex-start'
      },
      center: {
        justifyContent: 'center'
      },
      end: {
        justifyContent: 'flex-end'
      },
      between: {
        justifyContent: 'space-between'
      }
    },
    wrap: {
      noWrap: {
        flexWrap: 'nowrap'
      },
      wrap: {
        flexWrap: 'wrap'
      },
      wrapReverse: {
        flexWrap: 'wrap-reverse'
      }
    },
    gap: {
      inherit: {
        gap: 'inherit'
      },
      100: {
        gap: '$100'
      },
      200: {
        gap: '$200'
      },
      300: {
        gap: '$300'
      },
      400: {
        gap: '$400'
      },
      500: {
        gap: '$500'
      },
      600: {
        gap: '$600'
      },
      700: {
        gap: '$700'
      },
      800: {
        gap: '$800'
      },
      900: {
        gap: '$900'
      },
      1000: {
        gap: '$1000'
      },
      1100: {
        gap: '$1100'
      },
      1200: {
        gap: '$1200'
      },
      1300: {
        gap: '$1300'
      },
      1400: {
        gap: '$1400'
      },
      1500: {
        gap: '$1500'
      },
      1600: {
        gap: '$1600'
      }
    },
    columnGap: {
      100: {
        columnGap: '$100'
      },
      200: {
        columnGap: '$200'
      },
      300: {
        columnGap: '$300'
      },
      400: {
        columnGap: '$400'
      },
      500: {
        columnGap: '$500'
      },
      600: {
        columnGap: '$600'
      },
      700: {
        columnGap: '$700'
      },
      800: {
        columnGap: '$800'
      },
      900: {
        columnGap: '$900'
      },
      1000: {
        columnGap: '$1000'
      },
      1100: {
        columnGap: '$1100'
      },
      1200: {
        columnGap: '$1200'
      },
      1300: {
        columnGap: '$1300'
      },
      1400: {
        columnGap: '$1400'
      },
      1500: {
        columnGap: '$1500'
      },
      1600: {
        columnGap: '$1600'
      }
    },
    rowGap: {
      100: {
        rowGap: '$100'
      },
      200: {
        rowGap: '$200'
      },
      300: {
        rowGap: '$300'
      },
      400: {
        rowGap: '$400'
      },
      500: {
        rowGap: '$500'
      },
      600: {
        rowGap: '$600'
      },
      700: {
        rowGap: '$700'
      },
      800: {
        rowGap: '$800'
      },
      900: {
        rowGap: '$900'
      },
      1000: {
        rowGap: '$1000'
      },
      1100: {
        rowGap: '$1100'
      },
      1200: {
        rowGap: '$1200'
      },
      1300: {
        rowGap: '$1300'
      },
      1400: {
        rowGap: '$1400'
      },
      1500: {
        rowGap: '$1500'
      },
      1600: {
        rowGap: '$1600'
      }
    }
  },
  defaultVariants: {
    direction: 'row',
    align: 'stretch',
    justify: 'start',
    wrap: 'noWrap'
  }
});