"use strict";

exports.__esModule = true;
exports.NumberInput = void 0;
var _icons = require("../../../icons");
var _theme = require("../../../theme");
var _react = require("react");
var _formatInput = require("./formatInput");
var _jsxRuntime = require("react/jsx-runtime");
var _excluded = ["id", "defaultValue", "min", "max", "buttons", "definitionTimeout", "onChange", "onBlur"];
function _extends() { return _extends = Object.assign ? Object.assign.bind() : function (n) { for (var e = 1; e < arguments.length; e++) { var t = arguments[e]; for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]); } return n; }, _extends.apply(null, arguments); }
function _objectWithoutPropertiesLoose(r, e) { if (null == r) return {}; var t = {}; for (var n in r) if ({}.hasOwnProperty.call(r, n)) { if (e.indexOf(n) >= 0) continue; t[n] = r[n]; } return t; }
var Wrapper = (0, _theme.styled)('div', {
  display: 'flex',
  columnGap: '$100',
  alignItems: 'center'
});
var focusOutline = {
  '&:focus-visible': {
    outline: 'none',
    borderWidth: '$medium',
    borderColor: '$green60',
    boxShadow: '$green40'
  }
};
var Button = (0, _theme.styled)('button', focusOutline, {
  background: 'transparent',
  borderColor: '$gray30',
  borderRadius: '$circle',
  borderStyle: 'solid',
  borderWidth: '$thin',
  color: '$black',
  cursor: 'pointer',
  fontFamily: '$main',
  fontWeight: '$bold',
  width: '1.5rem',
  height: '1.5rem',
  display: 'inline-grid',
  placeItems: 'center',
  '&:disabled': {
    pointerEvents: 'none'
  }
});
var Input = (0, _theme.styled)('input', focusOutline, {
  borderColor: '$gray30',
  borderRadius: '$100',
  borderStyle: 'solid',
  borderWidth: '$thin',
  color: '$black',
  fontFamily: '$main',
  fontWeight: '$regular',
  fontSize: '$400',
  width: '3rem',
  height: '2rem',
  textAlign: 'center',
  '-moz-appearance': 'textfield',
  '&::-webkit-outer-spin-button, &::-webkit-inner-spin-button': {
    display: 'none'
  }
});
var inputEvent = function inputEvent() {
  return new Event('input', {
    bubbles: true
  });
};
var inputTimeout;
var NumberInput = exports.NumberInput = /*#__PURE__*/(0, _react.forwardRef)(function (props, ref) {
  var id = props.id,
    _props$defaultValue = props.defaultValue,
    defaultValue = _props$defaultValue === void 0 ? '1' : _props$defaultValue,
    _props$min = props.min,
    min = _props$min === void 0 ? '1' : _props$min,
    _props$max = props.max,
    max = _props$max === void 0 ? '9999' : _props$max,
    _props$buttons = props.buttons,
    _props$buttons2 = _props$buttons === void 0 ? {} : _props$buttons,
    decrease = _props$buttons2.decrease,
    increase = _props$buttons2.increase,
    _props$definitionTime = props.definitionTimeout,
    definitionTimeout = _props$definitionTime === void 0 ? 700 : _props$definitionTime,
    onChange = props.onChange,
    onBlur = props.onBlur,
    rest = _objectWithoutPropertiesLoose(props, _excluded);
  var inputRef = (0, _react.useRef)({});
  var _useState = (0, _react.useState)(min === defaultValue),
    isDecreaseDisabled = _useState[0],
    setIsDecreaseDisabled = _useState[1];
  var _useState2 = (0, _react.useState)(max === defaultValue),
    isIncreaseDisabled = _useState2[0],
    setIsIncreaseDisabled = _useState2[1];
  (0, _react.useImperativeHandle)(ref, function () {
    return inputRef.current;
  });
  function onStepDown(event) {
    inputRef.current.stepDown();
    inputRef.current.dispatchEvent(inputEvent());
    decrease == null || decrease.onClick == null || decrease.onClick(event);
  }
  function onStepUp(event) {
    inputRef.current.stepUp();
    inputRef.current.dispatchEvent(inputEvent());
    increase == null || increase.onClick == null || increase.onClick(event);
  }
  function handleChange(event) {
    clearTimeout(inputTimeout);
    var value = Number(inputRef.current.value);
    setIsDecreaseDisabled(value === Number(min));
    setIsIncreaseDisabled(value === Number(max));

    /**
     * If the value is empty, the user may want to digit it from scratch, so we
     * give all the time needed to it
     */
    if (inputRef.current.value !== '') {
      inputTimeout = setTimeout(function () {
        if (inputRef.current) {
          inputRef.current.value = (0, _formatInput.formatInput)({
            min: min,
            value: value,
            max: max
          });
        }
        onChange == null || onChange(event);
      }, definitionTimeout);
    }
  }
  function handleBlur(event) {
    var previousValue = inputRef.current.value;
    inputRef.current.value = (0, _formatInput.formatInput)({
      min: min,
      value: previousValue,
      max: max
    });
    if (previousValue !== inputRef.current.value) {
      inputRef.current.dispatchEvent(inputEvent());
    }
    onBlur == null || onBlur(event);
  }
  return /*#__PURE__*/(0, _jsxRuntime.jsxs)(Wrapper, {
    children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(Button, _extends({
      type: "button",
      "aria-label": "diminuir quantidade",
      "aria-controls": id
    }, decrease, {
      disabled: isDecreaseDisabled,
      onClick: onStepDown,
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_icons.Icon, {
        label: "less",
        size: "200",
        "aria-hidden": true
      })
    })), /*#__PURE__*/(0, _jsxRuntime.jsx)(Input, _extends({
      type: "number",
      defaultValue: defaultValue,
      min: min,
      max: max,
      "aria-live": "polite"
    }, rest, {
      id: id,
      onInput: handleChange,
      onBlur: handleBlur,
      ref: inputRef
    })), /*#__PURE__*/(0, _jsxRuntime.jsx)(Button, _extends({
      type: "button",
      "aria-label": "aumentar quantidade",
      "aria-controls": id
    }, increase, {
      disabled: isIncreaseDisabled,
      onClick: onStepUp,
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_icons.Icon, {
        label: "more",
        size: "200",
        "aria-hidden": true
      })
    }))]
  });
});
NumberInput.displayName = 'NumberInput';