"use strict";

exports.__esModule = true;
exports.PaginationLink = exports.Pagination = void 0;
var _react = require("react");
var _usePagination = require("./usePagination/usePagination");
var _theme = require("../../../theme");
var _jsxRuntime = require("react/jsx-runtime");
var _excluded = ["currentPage", "count", "siblingRange", "Item", "itemBackground"];
function _extends() { return _extends = Object.assign ? Object.assign.bind() : function (n) { for (var e = 1; e < arguments.length; e++) { var t = arguments[e]; for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]); } return n; }, _extends.apply(null, arguments); }
function _objectWithoutPropertiesLoose(r, e) { if (null == r) return {}; var t = {}; for (var n in r) if ({}.hasOwnProperty.call(r, n)) { if (e.indexOf(n) >= 0) continue; t[n] = r[n]; } return t; }
var PaginationContainer = (0, _theme.styled)('ul', {
  fontFamily: '$main',
  display: 'flex',
  listStyleType: 'none',
  columnGap: '$100'
});
var paginationItem = {
  border: 'none',
  display: 'inline-flex',
  alignItems: 'center',
  justifyContent: 'center',
  fontSize: 'inherit',
  width: '$space$800',
  height: '$space$800',
  userSelect: 'none',
  textAlign: 'center'
};
var PaginationDots = (0, _theme.styled)('div', paginationItem, {
  background: 'none'
});
var PaginationLink = exports.PaginationLink = (0, _theme.styled)('a', paginationItem, {
  cursor: 'pointer',
  borderRadius: '$200',
  color: '$black',
  textDecoration: 'none',
  fontFamily: '$main',
  '&:focus-visible': {
    outlineWidth: '$borderWidths$medium',
    outlineStyle: 'solid',
    outlineColor: '$gray50'
  },
  variants: {
    itemBackground: {
      gray10: {
        background: '$gray10'
      },
      white: {
        background: '$white'
      }
    },
    active: {
      "true": {
        background: '$green60 !important',
        color: '$white',
        fontWeight: '$bold'
      }
    },
    itemDisabled: {
      "true": {
        color: '$gray40',
        cursor: 'not-allowed'
      }
    }
  },
  compoundVariants: [{
    active: false,
    itemDisabled: false,
    css: {
      '&:hover': {
        background: '$gray20'
      }
    }
  }],
  defaultVariants: {
    active: false,
    itemDisabled: false,
    itemBackground: 'gray10'
  }
});
var getDisabledProps = function getDisabledProps(disabled) {
  if (!disabled) {
    return {};
  }
  return {
    disabled: disabled,
    itemDisabled: disabled,
    as: 'button',
    'aria-disabled': disabled
  };
};
var PaginationComponent = function PaginationComponent(_ref) {
  var currentPage = _ref.currentPage,
    count = _ref.count,
    _ref$siblingRange = _ref.siblingRange,
    siblingRange = _ref$siblingRange === void 0 ? 1 : _ref$siblingRange,
    Item = _ref.Item,
    itemBackground = _ref.itemBackground,
    props = _objectWithoutPropertiesLoose(_ref, _excluded);
  var paginationRange = (0, _usePagination.usePagination)({
    currentPage: currentPage,
    count: count,
    siblingRange: siblingRange
  });
  var hasNoPages = paginationRange.length < 1;
  if (hasNoPages) {
    return null;
  }
  var lastPage = paginationRange[paginationRange.length - 1];
  var disabled = {
    previous: currentPage === 1,
    next: currentPage === lastPage
  };
  return /*#__PURE__*/(0, _jsxRuntime.jsx)("nav", _extends({}, props, {
    children: /*#__PURE__*/(0, _jsxRuntime.jsxs)(PaginationContainer, {
      children: [/*#__PURE__*/(0, _jsxRuntime.jsx)("li", {
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(Item, _extends({
          itemBackground: itemBackground,
          "data-page-number": currentPage - 1,
          "aria-label": "ir para a p\xE1gina anterior",
          "data-anchor-type": "previous"
        }, getDisabledProps(disabled.previous), {
          children: "<"
        }))
      }), paginationRange.map(function (pageNumber, index) {
        if (pageNumber === _usePagination.DOTS) {
          return /*#__PURE__*/(0, _jsxRuntime.jsx)(PaginationDots, {
            tabIndex: -1,
            "aria-hidden": true,
            children: "\u2026"
          }, _usePagination.DOTS + index);
        }
        var isActive = currentPage === pageNumber;
        return /*#__PURE__*/(0, _jsxRuntime.jsx)("li", {
          children: /*#__PURE__*/(0, _jsxRuntime.jsx)(Item, {
            itemBackground: itemBackground,
            "data-page-number": Number(pageNumber),
            "data-anchor-type": "number",
            "aria-label": "ir para a p\xE1gina " + pageNumber,
            active: isActive,
            "aria-current": isActive ? 'page' : undefined,
            children: pageNumber
          })
        }, pageNumber);
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)("li", {
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(Item, _extends({
          itemBackground: itemBackground,
          "data-page-number": currentPage + 1,
          "data-anchor-type": "next",
          "aria-label": "ir para a pr\xF3xima p\xE1gina"
        }, getDisabledProps(disabled.next), {
          children: ">"
        }))
      })]
    })
  }));
};
var Pagination = exports.Pagination = /*#__PURE__*/(0, _react.memo)(PaginationComponent);