"use strict";

exports.__esModule = true;
exports.Range = void 0;
var Slider = _interopRequireWildcard(require("@radix-ui/react-slider"));
var _react = require("react");
var _theme = require("../../../theme");
var _Flex = require("../Flex");
var _Typography = require("../Typography");
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { "default": e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n["default"] = e, t && t.set(e, n), n; }
var SliderRoot = (0, _theme.styled)(Slider.Root, {
  alignItems: 'center',
  display: 'flex',
  height: '1.25rem',
  position: 'relative',
  touchAction: 'none',
  userSelect: 'none',
  width: '100%'
});
var SliderTrack = (0, _theme.styled)(Slider.Track, {
  backgroundColor: '$gray20',
  borderRadius: '9999px',
  flexGrow: 1,
  height: '0.25rem',
  position: 'relative'
});
var SliderRange = (0, _theme.styled)(Slider.Range, {
  backgroundColor: '$green40',
  borderRadius: '9999px',
  height: '100%',
  position: 'absolute'
});
var SliderThumb = (0, _theme.styled)(Slider.Thumb, {
  backgroundColor: '$green40',
  borderRadius: 10,
  boxShadow: '0 2px 10px $black',
  display: 'block',
  height: '1.313rem',
  width: '1.313rem',
  '&:hover': {
    backgroundColor: '$green40'
  },
  '&:focus': {
    outline: 'none',
    boxShadow: "0 0 0 5px $green40"
  }
});
var formatCurrency = function formatCurrency(value) {
  return new Intl.NumberFormat('pt-BR', {
    style: 'currency',
    currency: 'BRL'
  }).format(value);
};
var displayValue = function displayValue(value, isCurrency) {
  var formattedValue = formatCurrency(value);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_Typography.Typography, {
    size: '300',
    weight: 'medium',
    color: 'gray50',
    children: isCurrency ? formattedValue : value
  });
};
var Range = exports.Range = /*#__PURE__*/(0, _react.forwardRef)(function (props, ref) {
  var _props$isCurrency = props.isCurrency,
    isCurrency = _props$isCurrency === void 0 ? false : _props$isCurrency,
    minValue = props.minValue,
    maxValue = props.maxValue,
    step = props.step,
    _props$startValues = props.startValues,
    startValues = _props$startValues === void 0 ? [minValue, maxValue] : _props$startValues,
    onValueCommit = props.onValueCommit;
  var _useState = (0, _react.useState)(startValues),
    rangeValues = _useState[0],
    setRangeValues = _useState[1];
  var handleValueChange = (0, _react.useCallback)(function (newRangeValues) {
    setRangeValues(newRangeValues);
  }, []);
  return /*#__PURE__*/(0, _jsxRuntime.jsxs)(_Flex.Flex, {
    direction: "column",
    children: [/*#__PURE__*/(0, _jsxRuntime.jsxs)(SliderRoot, {
      min: minValue,
      max: maxValue,
      value: rangeValues,
      minStepsBetweenThumbs: 0.1,
      onValueChange: handleValueChange,
      step: step || 1,
      ref: ref,
      onValueCommit: onValueCommit,
      children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(SliderTrack, {
        "data-testid": "slider-track",
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(SliderRange, {})
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(SliderThumb, {
        "aria-label": "Menor valor"
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(SliderThumb, {
        "aria-label": "Maior valor"
      })]
    }), /*#__PURE__*/(0, _jsxRuntime.jsxs)(_Flex.Flex, {
      justify: "between",
      css: {
        marginTop: '$100'
      },
      children: [displayValue(rangeValues[0], isCurrency), displayValue(rangeValues[1], isCurrency)]
    })]
  });
});
Range.displayName = 'Range';