"use strict";

exports.__esModule = true;
exports.SelectItem = exports.Select = void 0;
var _theme = require("../../../theme");
var SelectPrimitive = _interopRequireWildcard(require("@radix-ui/react-select"));
var _icons = require("../../../icons");
var _react = require("react");
var _Divider = require("../Divider");
var _FormControl = require("../FormControl");
var _Overlay = require("./Overlay");
var _jsxRuntime = require("react/jsx-runtime");
var _excluded = ["children", "ariaLabel", "placeholder", "errorMessage", "error", "required", "label", "open", "onOpenChange", "direction", "className", "css"],
  _excluded2 = ["children"];
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { "default": e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n["default"] = e, t && t.set(e, n), n; }
function _objectWithoutPropertiesLoose(r, e) { if (null == r) return {}; var t = {}; for (var n in r) if ({}.hasOwnProperty.call(r, n)) { if (e.indexOf(n) >= 0) continue; t[n] = r[n]; } return t; }
function _extends() { return _extends = Object.assign ? Object.assign.bind() : function (n) { for (var e = 1; e < arguments.length; e++) { var t = arguments[e]; for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]); } return n; }, _extends.apply(null, arguments); }
var StyledTrigger = (0, _theme.styled)(SelectPrimitive.SelectTrigger, {
  all: 'unset',
  boxSizing: 'border-box',
  width: '100%',
  borderStyle: 'solid',
  borderWidth: '$thin',
  borderColor: '$gray30',
  borderRadius: '$200',
  height: '3.625rem',
  margin: '$200 0',
  gap: '$400',
  padding: '0 $400',
  background: '$white',
  display: 'inline-flex',
  alignItems: 'center',
  justifyContent: 'space-between',
  fontFamily: '$main',
  color: '$gray50',
  fontSize: '$400',
  cursor: 'pointer',
  '&[data-state="open"]': {
    zIndex: '$max'
  },
  '&:focus': {
    borderColor: '$green30',
    boxShadow: '$green40'
  },
  variants: {
    hasError: {
      "true": {
        borderColor: '$red40',
        boxShadow: '$red40'
      },
      "false": {}
    }
  },
  '&:first-child > span:first-child': {
    whiteSpace: 'nowrap',
    width: 'calc(100% - 3.5rem)',
    overflow: 'hidden',
    textOverflow: 'ellipsis'
  }
});
var StyledIcon = (0, _theme.styled)(SelectPrimitive.Icon, {
  display: 'flex'
});
var StyledContent = (0, _theme.styled)(SelectPrimitive.Content, {
  overflow: 'hidden',
  position: 'absolute',
  background: '$white',
  width: '100%',
  borderRadius: '$200',
  borderStyle: 'solid',
  borderWidth: '$thin',
  borderColor: '$gray30',
  '&[data-state="open"]': {
    zIndex: '$max'
  }
});
var StyledItem = (0, _theme.styled)(SelectPrimitive.Item, {
  all: 'unset',
  display: 'flex',
  padding: '$500 $1000 $500 $400',
  fontFamily: '$main',
  color: '$gray50',
  fontSize: '$400',
  cursor: 'pointer',
  lineHeight: '$tight',
  justifyContent: 'space-between',
  alignItems: 'center',
  position: 'relative',
  userSelect: 'none',
  '&[data-state="checked"]': {
    background: '$gray10'
  },
  '&:focus-visible': {
    '&:before': {
      content: '',
      position: 'absolute',
      inset: 0,
      borderColor: '$green60',
      borderWidth: '$borderWidths$thin',
      borderStyle: 'solid',
      borderRadius: '$200',
      boxShadow: '$green40'
    }
  },
  '&:hover': {
    color: '$green60',
    outline: 'none'
  },
  '&[data-disabled]': {
    cursor: 'not-allowed',
    background: '$gray20',
    color: '$gray30'
  }
});
var StyledItemIndicator = (0, _theme.styled)(SelectPrimitive.ItemIndicator, {
  position: 'absolute',
  right: '$400',
  display: 'inline-flex',
  alignItems: 'center',
  justifyContent: 'center'
});
var scrollButtonStyles = {
  display: 'flex',
  alignItems: 'center',
  justifyContent: 'center',
  height: '1.563rem'
};
var StyledScrollUpButton = (0, _theme.styled)(SelectPrimitive.ScrollUpButton, _extends({}, scrollButtonStyles, {
  cursor: 'n-resize'
}));
var StyledScrollDownButton = (0, _theme.styled)(SelectPrimitive.ScrollDownButton, _extends({}, scrollButtonStyles, {
  cursor: 's-resize'
}));
var StyledDivider = (0, _theme.styled)(_Divider.Divider, {
  '&:first-of-type': {
    display: 'none'
  }
});
var Select = exports.Select = /*#__PURE__*/(0, _react.forwardRef)(function (_ref, forwardedRef) {
  var children = _ref.children,
    ariaLabel = _ref.ariaLabel,
    placeholder = _ref.placeholder,
    errorMessage = _ref.errorMessage,
    error = _ref.error,
    required = _ref.required,
    label = _ref.label,
    _ref$open = _ref.open,
    open = _ref$open === void 0 ? false : _ref$open,
    onOpenChange = _ref.onOpenChange,
    direction = _ref.direction,
    className = _ref.className,
    css = _ref.css,
    props = _objectWithoutPropertiesLoose(_ref, _excluded);
  var generatedId = (0, _react.useId)();
  var _useState = (0, _react.useState)(open),
    visible = _useState[0],
    setVisible = _useState[1];
  function handleOpenChange(isOpen) {
    onOpenChange == null || onOpenChange(isOpen);
    setVisible(isOpen);
  }
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_FormControl.FormControl, {
    id: generatedId,
    label: label,
    error: error,
    errorMessage: errorMessage,
    required: required,
    direction: direction,
    className: className,
    css: css,
    children: /*#__PURE__*/(0, _jsxRuntime.jsxs)(SelectPrimitive.Root, _extends({}, props, {
      open: visible,
      onOpenChange: handleOpenChange,
      children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_Overlay.Overlay, {
        open: visible
      }), /*#__PURE__*/(0, _jsxRuntime.jsxs)(StyledTrigger, {
        "aria-label": ariaLabel,
        ref: forwardedRef,
        hasError: error,
        id: generatedId,
        children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(SelectPrimitive.Value, {
          placeholder: placeholder
        }), /*#__PURE__*/(0, _jsxRuntime.jsx)(StyledIcon, {
          children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_icons.Icon, {
            label: "chevron-down",
            size: "600",
            fill: "gray50"
          })
        })]
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(SelectPrimitive.Portal, {
        children: /*#__PURE__*/(0, _jsxRuntime.jsxs)(StyledContent, {
          children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(StyledScrollUpButton, {
            children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_icons.Icon, {
              label: "chevron-up",
              size: "600",
              fill: "gray50"
            })
          }), /*#__PURE__*/(0, _jsxRuntime.jsx)(SelectPrimitive.Viewport, {
            children: children
          }), /*#__PURE__*/(0, _jsxRuntime.jsx)(StyledScrollDownButton, {
            children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_icons.Icon, {
              label: "chevron-down",
              size: "600",
              fill: "gray50"
            })
          })]
        })
      })]
    }))
  });
});
Select.displayName = 'Select';
var SelectItem = exports.SelectItem = /*#__PURE__*/(0, _react.forwardRef)(function (_ref2, forwardedRef) {
  var children = _ref2.children,
    props = _objectWithoutPropertiesLoose(_ref2, _excluded2);
  return /*#__PURE__*/(0, _jsxRuntime.jsxs)(_jsxRuntime.Fragment, {
    children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(StyledDivider, {}), /*#__PURE__*/(0, _jsxRuntime.jsxs)(StyledItem, _extends({}, props, {
      ref: forwardedRef,
      children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(SelectPrimitive.ItemText, {
        children: children
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(StyledItemIndicator, {
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_icons.Icon, {
          label: "check",
          size: "600",
          fill: "gray50"
        })
      })]
    }))]
  });
});
SelectItem.displayName = 'SelectItem';