"use strict";

exports.__esModule = true;
exports.TextInput = void 0;
var _react = require("react");
var _icons = require("../../../icons");
var _theme = require("../../../theme");
var _ = require("..");
var _FormControl = require("../FormControl");
var _jsxRuntime = require("react/jsx-runtime");
var _excluded = ["label", "error", "errorMessage", "tooltipMessage", "loading", "link", "endAdornment", "disabled", "onFocus", "onBlur", "readOnly", "required", "id", "direction", "className", "css"];
var _styled;
function _extends() { return _extends = Object.assign ? Object.assign.bind() : function (n) { for (var e = 1; e < arguments.length; e++) { var t = arguments[e]; for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]); } return n; }, _extends.apply(null, arguments); }
function _objectWithoutPropertiesLoose(r, e) { if (null == r) return {}; var t = {}; for (var n in r) if ({}.hasOwnProperty.call(r, n)) { if (e.indexOf(n) >= 0) continue; t[n] = r[n]; } return t; }
var Input = (0, _theme.styled)('input', {
  all: 'unset',
  border: 'none',
  outline: 'none',
  width: '100%',
  color: '$gray50',
  fontSize: '$400',
  boxSizing: 'border-box',
  fontFamily: '$main',
  padding: '$500 $400',
  '&::placeholder': {
    color: '$gray30',
    fontSize: '$400'
  },
  '&:disabled': {
    background: 'transparent',
    cursor: 'default'
  },
  '&::-webkit-inner-spin-button': {
    '-webkit-appearance': 'none',
    margin: 0
  },
  '&[type=number]': {
    '-moz-appearance': 'textfield'
  },
  '&:-webkit-autofill, &:-webkit-autofill:hover, &:-webkit-autofill:focus, &:-webkit-autofill::first-line': {
    '-webkit-background-clip': 'text',
    '-webkit-border': 'none',
    '-webkit-box-shadow': 'none',
    'background-clip': 'text',
    boxShadow: 'none',
    border: 'none'
  }
});
var InputContainer = (0, _theme.styled)('div', (_styled = {
  display: 'flex',
  width: '100%',
  borderStyle: 'solid',
  borderWidth: '$thin',
  borderColor: 'transparent',
  borderRadius: '$200',
  height: '3.625rem',
  position: 'relative',
  inset: 0
}, _styled["& .end-adornment-container > svg, & [data-name=\"ghost-icon-button\"]"] = {
  marginRight: '$400'
}, _styled.variants = {
  disabled: {
    "true": {
      background: '$gray20'
    },
    "false": {
      background: '$white'
    }
  },
  error: {
    "true": {},
    "false": {}
  },
  focused: {
    "true": {},
    "false": {}
  }
}, _styled.compoundVariants = [{
  error: false,
  focused: false,
  disabled: false,
  css: {
    borderColor: '$gray30'
  }
}, {
  error: false,
  focused: true,
  disabled: false,
  css: {
    borderColor: '$green30',
    boxShadow: '$green40'
  }
}, {
  error: true,
  focused: false,
  disabled: false,
  css: {
    borderColor: '$red40',
    boxShadow: '$red40'
  }
}, {
  error: true,
  focused: true,
  disabled: false,
  css: {
    borderColor: '$green30',
    boxShadow: '$green40'
  }
}], _styled));
var TextInput = exports.TextInput = /*#__PURE__*/(0, _react.forwardRef)(function (_ref, ref) {
  var label = _ref.label,
    _ref$error = _ref.error,
    error = _ref$error === void 0 ? false : _ref$error,
    errorMessage = _ref.errorMessage,
    tooltipMessage = _ref.tooltipMessage,
    loading = _ref.loading,
    link = _ref.link,
    endAdornment = _ref.endAdornment,
    _ref$disabled = _ref.disabled,
    disabled = _ref$disabled === void 0 ? false : _ref$disabled,
    _onFocus = _ref.onFocus,
    _onBlur = _ref.onBlur,
    readOnly = _ref.readOnly,
    required = _ref.required,
    id = _ref.id,
    direction = _ref.direction,
    className = _ref.className,
    css = _ref.css,
    props = _objectWithoutPropertiesLoose(_ref, _excluded);
  var _useState = (0, _react.useState)(false),
    focused = _useState[0],
    setFocused = _useState[1];
  var generatedId = (0, _react.useId)();
  var localId = id != null ? id : generatedId;
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_FormControl.FormControl, {
    id: localId,
    label: label,
    required: required,
    error: error,
    errorMessage: errorMessage,
    tooltipMessage: tooltipMessage,
    link: link,
    direction: direction,
    className: className,
    css: css,
    overflow: "unset",
    children: /*#__PURE__*/(0, _jsxRuntime.jsxs)(InputContainer, {
      "data-testid": "input-container",
      focused: focused,
      error: error,
      disabled: disabled,
      "aria-busy": loading,
      children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(Input, _extends({
        ref: ref,
        onFocus: function onFocus(event) {
          setFocused(true);
          _onFocus == null || _onFocus(event);
        },
        onBlur: function onBlur(event) {
          setFocused(false);
          _onBlur == null || _onBlur(event);
        },
        disabled: disabled,
        readOnly: readOnly || loading,
        "aria-invalid": error,
        "aria-describedby": error ? localId + "-error" : undefined,
        required: required
      }, props, {
        id: localId
      })), /*#__PURE__*/(0, _jsxRuntime.jsxs)(_.Flex, {
        className: "end-adornment-container",
        align: "center",
        css: {
          margin: '-$borderWidths$thin'
        },
        children: [loading && /*#__PURE__*/(0, _jsxRuntime.jsx)(_icons.Icon, {
          label: "loading",
          size: "600",
          fill: "gray50",
          animate: "rotate"
        }), !loading && endAdornment]
      })]
    })
  });
});
TextInput.displayName = 'TextInput';