"use strict";

exports.__esModule = true;
exports.Tooltip = Tooltip;
exports.TooltipProvider = void 0;
var _react = require("react");
var TooltipPrimitive = _interopRequireWildcard(require("@radix-ui/react-tooltip"));
var _theme = require("../../../theme");
var _utils = require("../../utils");
var _jsxRuntime = require("react/jsx-runtime");
var _excluded = ["children", "content", "open", "defaultOpen", "onOpenChange", "side"];
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { "default": e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n["default"] = e, t && t.set(e, n), n; }
function _extends() { return _extends = Object.assign ? Object.assign.bind() : function (n) { for (var e = 1; e < arguments.length; e++) { var t = arguments[e]; for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]); } return n; }, _extends.apply(null, arguments); }
function _objectWithoutPropertiesLoose(r, e) { if (null == r) return {}; var t = {}; for (var n in r) if ({}.hasOwnProperty.call(r, n)) { if (e.indexOf(n) >= 0) continue; t[n] = r[n]; } return t; }
var slideUpAndFade = (0, _theme.keyframes)({
  '0%': {
    opacity: 0,
    transform: 'translateY(0.125rem)'
  },
  '100%': {
    opacity: 1,
    transform: 'translateY(0)'
  }
});
var slideRightAndFade = (0, _theme.keyframes)({
  '0%': {
    opacity: 0,
    transform: 'translateX(-0.125rem)'
  },
  '100%': {
    opacity: 1,
    transform: 'translateX(0)'
  }
});
var slideDownAndFade = (0, _theme.keyframes)({
  '0%': {
    opacity: 0,
    transform: 'translateY(-0.125rem)'
  },
  '100%': {
    opacity: 1,
    transform: 'translateY(0)'
  }
});
var slideLeftAndFade = (0, _theme.keyframes)({
  '0%': {
    opacity: 0,
    transform: 'translateX(0.125rem)'
  },
  '100%': {
    opacity: 1,
    transform: 'translateX(0)'
  }
});
var Content = (0, _theme.styled)(TooltipPrimitive.Content, {
  fontFamily: '$main',
  fontSize: '$300',
  backgroundColor: '$gray50',
  borderRadius: '$200',
  padding: '$300 $500',
  maxWidth: '20rem',
  color: '$gray10',
  '@prefersMotion': {
    animationDuration: '400ms',
    animationTimingFunction: 'cubic-bezier(0.16, 1, 0.3, 1)',
    animationFillMode: 'forwards',
    willChange: 'transform, opacity',
    '&[data-state="delayed-open"]': {
      '&[data-side="top"]': {
        animationName: slideDownAndFade
      },
      '&[data-side="right"]': {
        animationName: slideLeftAndFade
      },
      '&[data-side="bottom"]': {
        animationName: slideUpAndFade
      },
      '&[data-side="left"]': {
        animationName: slideRightAndFade
      }
    }
  }
});
var Arrow = (0, _theme.styled)(TooltipPrimitive.Arrow, {
  fill: '$gray50'
});
var TooltipProvider = exports.TooltipProvider = TooltipPrimitive.Provider;
function Tooltip(_ref) {
  var children = _ref.children,
    content = _ref.content,
    open = _ref.open,
    defaultOpen = _ref.defaultOpen,
    onOpenChange = _ref.onOpenChange,
    _ref$side = _ref.side,
    side = _ref$side === void 0 ? 'top' : _ref$side,
    props = _objectWithoutPropertiesLoose(_ref, _excluded);
  /**
   * The Radix Tooltip does not open after a touch. This mechanism was included
   * because it is desired to allow content visualization on all devices
   */
  var _useState = (0, _react.useState)(undefined),
    display = _useState[0],
    setDisplay = _useState[1];
  var otherProps = (0, _utils.omit)(props, 'ref');
  var forceOpenState = display ? {
    open: display
  } : {};
  function onTouchEnd() {
    setDisplay(function (previousDisplay) {
      return !previousDisplay;
    });
  }
  function onBlur() {
    setDisplay(false);
  }
  return /*#__PURE__*/(0, _jsxRuntime.jsxs)(TooltipPrimitive.Root, _extends({
    open: open,
    defaultOpen: defaultOpen,
    onOpenChange: onOpenChange,
    delayDuration: 100
  }, forceOpenState, {
    children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(TooltipPrimitive.Trigger, {
      type: "button",
      asChild: true,
      onTouchEnd: onTouchEnd,
      onBlur: onBlur,
      children: children
    }), /*#__PURE__*/(0, _jsxRuntime.jsxs)(Content, _extends({
      side: side,
      sideOffset: 4
    }, otherProps, {
      children: [content, /*#__PURE__*/(0, _jsxRuntime.jsx)(Arrow, {
        width: 11,
        height: 5
      })]
    }))]
  }));
}