"use strict";

require("@testing-library/jest-dom");
var _test = require("../core/test");
/**
 * jest-dom adds custom jest matchers for asserting on DOM nodes.
 * allows you to do things like:
 *
 * expect(element).toHaveTextContent(/react/i)
 *
 * @see https://github.com/testing-library/jest-dom
 */

/**
 * this is used to create the matchMedia property on the window
 * so we can mock it on tests with spyOn
 */
(0, _test.mockInitialMedia)();

/**
 * JSDOM doesn't implement PointerEvent so we need to mock our own implementation
 * Default to mouse left click interaction
 *
 * @see https://github.com/radix-ui/primitives/issues/1382
 * @see https://github.com/radix-ui/primitives/issues/1207
 * @see https://github.com/radix-ui/primitives/issues/1822
 * @see https://github.com/jsdom/jsdom/pull/2666
 */
window.HTMLElement.prototype.scrollIntoView = jest.fn();
window.HTMLElement.prototype.releasePointerCapture = jest.fn();
window.HTMLElement.prototype.hasPointerCapture = jest.fn();
window.HTMLElement.prototype.setPointerCapture = jest.fn();

/**
 * this is necessary to tests components with ResizeObserver
 *
 * @see https://stackoverflow.com/questions/64558062/how-to-mock-resizeobserver-to-work-in-unit-tests-using-react-testing-library
 */
global.ResizeObserver = require('resize-observer-polyfill');